@@ -149,11 +149,17 @@ class NaPoleonBinanceFutureBot(object):
 
         position_threshold_reached = True
         if Ebtc > minBTC:
+            print('current BTC position '+str(PBTC))
+            print('target BTC position ' + str(Tbtc))
             coursbtc = float(ticker_data['BTC/USDT']['info']['bidPrice']) - 1
+            print('creating order buy at '+str(coursbtc) + ' for amount '+str(Ebtc))
             self.exchange.create_order(symbol='BTC/USDT', type='limit', side='buy', amount=Ebtc, price=coursbtc)
             position_threshold_reached = False
         elif Ebtc < -minBTC:
+            print('current BTC position '+str(PBTC))
+            print('target BTC position ' + str(Tbtc))
             coursbtc = float(ticker_data['BTC/USDT']['info']['askPrice']) + 1
+            print('creating order buy at '+str(coursbtc) + ' for amount '+str(Ebtc))
             self.exchange.create_order(symbol='BTC/USDT', type='limit', side='sell', amount=abs(Ebtc), price=coursbtc)
             position_threshold_reached = False
 
