@@ -592,10 +592,10 @@ class RealTimeSignalEnsemblingParalleLauncher():
             raise Exception('not implemented yet')
         running_date = datetime.now()
         starting_date = running_date - timedelta(days=nb_last_days)
-        freqly_pkl_file_name_suffix = '_day_tmp.pkl'
-        hours_df = napoleon_connector.fetch_crypto_minutely_data(ssj=self.underlying,
+        freqly_pkl_file_name_suffix = '_hour_tmp.pkl'
+        hours_df = napoleon_connector.fetch_crypto_hourly_data(ssj=self.underlying,
                                                                  local_root_directory=self.local_root_directory,
-                                                                 minutely_return_pkl_filename_suffix=freqly_pkl_file_name_suffix,
+                                                                 hourly_return_pkl_filename_suffix=freqly_pkl_file_name_suffix,
                                                                  daily_crypto_starting_day=starting_date,
                                                                  daily_crypto_ending_day=running_date,
                                                                  refetch_all=True)
