@@ -144,9 +144,9 @@ def alpha_5_ls(data = None, vol_threshold = 0.8, contravariant = -1., lag = 2, *
     high = data.groupby(['aggregated_indice'])['high'].agg('max')
     low = data.groupby(['aggregated_indice'])['low'].agg('min')
 
-    data['aggregated_volume'] =  data['aggregated_indice'].map(volumefrom)
-    data['aggregated_high'] =  data['aggregated_indice'].map(high)
-    data['aggregated_low'] =  data['aggregated_indice'].map(low)
+    data['aggregated_volume'] =  data['aggregated_indice'].map(volumefrom).copy()
+    data['aggregated_high'] =  data['aggregated_indice'].map(high).copy()
+    data['aggregated_low'] =  data['aggregated_indice'].map(low).copy()
 
     data = data[::-lag]
     data = data.iloc[::-1]
@@ -200,9 +200,9 @@ def alpha_6_lo(data = None, vol_threshold = 0.8, up_trend_threshold=0.8, contrav
     high = data.groupby(['aggregated_indice'])['high'].agg('max')
     low = data.groupby(['aggregated_indice'])['low'].agg('min')
 
-    data['aggregated_volume'] =  data['aggregated_indice'].map(volumefrom)
-    data['aggregated_high'] =  data['aggregated_indice'].map(high)
-    data['aggregated_low'] =  data['aggregated_indice'].map(low)
+    data['aggregated_volume'] =  data['aggregated_indice'].map(volumefrom).copy()
+    data['aggregated_high'] =  data['aggregated_indice'].map(high).copy()
+    data['aggregated_low'] =  data['aggregated_indice'].map(low).copy()
 
     data = data[::-lag]
     data = data.iloc[::-1]
@@ -241,9 +241,9 @@ def alpha_6_ls(data = None, vol_threshold = 0.8, contravariant = -1., lag = 2, *
     high = data.groupby(['aggregated_indice'])['high'].agg('max')
     low = data.groupby(['aggregated_indice'])['low'].agg('min')
 
-    data['aggregated_volume'] =  data['aggregated_indice'].map(volumefrom)
-    data['aggregated_high'] =  data['aggregated_indice'].map(high)
-    data['aggregated_low'] =  data['aggregated_indice'].map(low)
+    data['aggregated_volume'] =  data['aggregated_indice'].map(volumefrom).copy()
+    data['aggregated_high'] =  data['aggregated_indice'].map(high).copy()
+    data['aggregated_low'] =  data['aggregated_indice'].map(low).copy()
 
     data = data[::-lag]
     data = data.iloc[::-1]
@@ -424,9 +424,9 @@ def volume_weighted_high_low_vol_lo(data = None, vol_threshold = 0.8, up_trend_t
     high = data.groupby(['aggregated_indice'])['high'].agg('max')
     low = data.groupby(['aggregated_indice'])['low'].agg('min')
 
-    data['aggregated_volume'] =  data['aggregated_indice'].map(volumefrom)
-    data['aggregated_high'] =  data['aggregated_indice'].map(high)
-    data['aggregated_low'] =  data['aggregated_indice'].map(low)
+    data['aggregated_volume'] =  data['aggregated_indice'].map(volumefrom).copy()
+    data['aggregated_high'] =  data['aggregated_indice'].map(high).copy()
+    data['aggregated_low'] =  data['aggregated_indice'].map(low).copy()
 
     data = data[::-lag]
     data = data.iloc[::-1]
@@ -472,9 +472,9 @@ def volume_weighted_high_low_vol_ls(data = None, vol_threshold = 0.8, up_trend_t
     high = data.groupby(['aggregated_indice'])['high'].agg('max')
     low = data.groupby(['aggregated_indice'])['low'].agg('min')
 
-    data['aggregated_volume'] =  data['aggregated_indice'].map(volumefrom)
-    data['aggregated_high'] =  data['aggregated_indice'].map(high)
-    data['aggregated_low'] =  data['aggregated_indice'].map(low)
+    data['aggregated_volume'] =  data['aggregated_indice'].map(volumefrom).copy()
+    data['aggregated_high'] =  data['aggregated_indice'].map(high).copy()
+    data['aggregated_low'] =  data['aggregated_indice'].map(low).copy()
 
     data = data[::-lag]
     data = data.iloc[::-1]
@@ -588,9 +588,9 @@ def volume_slope_ls(data = None, contravariant = -1., up_trend_threshold=0.8, lo
     high = data.groupby(['aggregated_indice'])['high'].agg('max')
     low = data.groupby(['aggregated_indice'])['low'].agg('min')
 
-    data['aggregated_volume'] =  data['aggregated_indice'].map(volumefrom)
-    data['aggregated_high'] =  data['aggregated_indice'].map(high)
-    data['aggregated_low'] =  data['aggregated_indice'].map(low)
+    data['aggregated_volume'] =  data['aggregated_indice'].map(volumefrom).copy()
+    data['aggregated_high'] =  data['aggregated_indice'].map(high).copy()
+    data['aggregated_low'] =  data['aggregated_indice'].map(low).copy()
 
     data = data[::-lag]
     data = data.iloc[::-1]
@@ -639,9 +639,9 @@ def volume_slope_lo(data = None, contravariant = -1., up_trend_threshold=0.8, pe
     high = data.groupby(['aggregated_indice'])['high'].agg('max')
     low = data.groupby(['aggregated_indice'])['low'].agg('min')
 
-    data['aggregated_volume'] =  data['aggregated_indice'].map(volumefrom)
-    data['aggregated_high'] =  data['aggregated_indice'].map(high)
-    data['aggregated_low'] =  data['aggregated_indice'].map(low)
+    data['aggregated_volume'] =  data['aggregated_indice'].map(volumefrom).copy()
+    data['aggregated_high'] =  data['aggregated_indice'].map(high).copy()
+    data['aggregated_low'] =  data['aggregated_indice'].map(low).copy()
 
     data = data[::-lag]
     data = data.iloc[::-1]
@@ -687,9 +687,9 @@ def volume_trending_rank_lo(data = None, contravariant = -1., up_trend_threshold
     high = data.groupby(['aggregated_indice'])['high'].agg('max')
     low = data.groupby(['aggregated_indice'])['low'].agg('min')
 
-    data['aggregated_volume'] =  data['aggregated_indice'].map(volumefrom)
-    data['aggregated_high'] =  data['aggregated_indice'].map(high)
-    data['aggregated_low'] =  data['aggregated_indice'].map(low)
+    data['aggregated_volume'] =  data['aggregated_indice'].map(volumefrom).copy()
+    data['aggregated_high'] =  data['aggregated_indice'].map(high).copy()
+    data['aggregated_low'] =  data['aggregated_indice'].map(low).copy()
 
     data = data[::-lag]
     data = data.iloc[::-1]
@@ -735,9 +735,9 @@ def volume_trending_rank_ls(data = None, contravariant = -1., up_trend_threshold
     high = data.groupby(['aggregated_indice'])['high'].agg('max')
     low = data.groupby(['aggregated_indice'])['low'].agg('min')
 
-    data['aggregated_volume'] =  data['aggregated_indice'].map(volumefrom)
-    data['aggregated_high'] =  data['aggregated_indice'].map(high)
-    data['aggregated_low'] =  data['aggregated_indice'].map(low)
+    data['aggregated_volume'] =  data['aggregated_indice'].map(volumefrom).copy()
+    data['aggregated_high'] =  data['aggregated_indice'].map(high).copy()
+    data['aggregated_low'] =  data['aggregated_indice'].map(low).copy()
 
     data = data[::-lag]
     data = data.iloc[::-1]
@@ -782,9 +782,9 @@ def trending_rank_lo_induced(data = None, contravariant = -1., up_trend_threshol
     high = data.groupby(['aggregated_indice'])['high'].agg('max')
     low = data.groupby(['aggregated_indice'])['low'].agg('min')
 
-    data['aggregated_volume'] =  data['aggregated_indice'].map(volumefrom)
-    data['aggregated_high'] =  data['aggregated_indice'].map(high)
-    data['aggregated_low'] =  data['aggregated_indice'].map(low)
+    data['aggregated_volume'] =  data['aggregated_indice'].map(volumefrom).copy()
+    data['aggregated_high'] =  data['aggregated_indice'].map(high).copy()
+    data['aggregated_low'] =  data['aggregated_indice'].map(low).copy()
 
     data = data[::-lag]
     data = data.iloc[::-1]
@@ -826,9 +826,9 @@ def slope_lo_induced(data = None, contravariant = -1., up_trend_threshold=0.8, p
     high = data.groupby(['aggregated_indice'])['high'].agg('max')
     low = data.groupby(['aggregated_indice'])['low'].agg('min')
 
-    data['aggregated_volume'] =  data['aggregated_indice'].map(volumefrom)
-    data['aggregated_high'] =  data['aggregated_indice'].map(high)
-    data['aggregated_low'] =  data['aggregated_indice'].map(low)
+    data['aggregated_volume'] =  data['aggregated_indice'].map(volumefrom).copy()
+    data['aggregated_high'] =  data['aggregated_indice'].map(high).copy()
+    data['aggregated_low'] =  data['aggregated_indice'].map(low).copy()
 
     data = data[::-lag]
     data = data.iloc[::-1]
@@ -874,9 +874,9 @@ def slope_lo_to_ls(data = None, contravariant = -1., up_trend_threshold=0.8, up_
     high = data.groupby(['aggregated_indice'])['high'].agg('max')
     low = data.groupby(['aggregated_indice'])['low'].agg('min')
 
-    data['aggregated_volume'] =  data['aggregated_indice'].map(volumefrom)
-    data['aggregated_high'] =  data['aggregated_indice'].map(high)
-    data['aggregated_low'] =  data['aggregated_indice'].map(low)
+    data['aggregated_volume'] =  data['aggregated_indice'].map(volumefrom).copy()
+    data['aggregated_high'] =  data['aggregated_indice'].map(high).copy()
+    data['aggregated_low'] =  data['aggregated_indice'].map(low).copy()
 
     data = data[::-lag]
     data = data.iloc[::-1]
@@ -954,9 +954,9 @@ def slope_ls(data = None, contravariant = -1., up_trend_threshold=0.8, low_trend
     high = data.groupby(['aggregated_indice'])['high'].agg('max')
     low = data.groupby(['aggregated_indice'])['low'].agg('min')
 
-    data['aggregated_volume'] =  data['aggregated_indice'].map(volumefrom)
-    data['aggregated_high'] =  data['aggregated_indice'].map(high)
-    data['aggregated_low'] =  data['aggregated_indice'].map(low)
+    data['aggregated_volume'] =  data['aggregated_indice'].map(volumefrom).copy()
+    data['aggregated_high'] =  data['aggregated_indice'].map(high).copy()
+    data['aggregated_low'] =  data['aggregated_indice'].map(low).copy()
 
     data = data[::-lag]
     data = data.iloc[::-1]
@@ -1004,9 +1004,9 @@ def trending_rank_ls(data = None, contravariant = -1., up_trend_threshold=0.8, l
     high = data.groupby(['aggregated_indice'])['high'].agg('max')
     low = data.groupby(['aggregated_indice'])['low'].agg('min')
 
-    data['aggregated_volume'] =  data['aggregated_indice'].map(volumefrom)
-    data['aggregated_high'] =  data['aggregated_indice'].map(high)
-    data['aggregated_low'] =  data['aggregated_indice'].map(low)
+    data['aggregated_volume'] =  data['aggregated_indice'].map(volumefrom).copy()
+    data['aggregated_high'] =  data['aggregated_indice'].map(high).copy()
+    data['aggregated_low'] =  data['aggregated_indice'].map(low).copy()
 
     data = data[::-lag]
     data = data.iloc[::-1]
@@ -1050,9 +1050,9 @@ def slope_induced_cont(data = None, contravariant = -1., lag = 2, slope_column =
     high = data.groupby(['aggregated_indice'])['high'].agg('max')
     low = data.groupby(['aggregated_indice'])['low'].agg('min')
 
-    data['aggregated_volume'] =  data['aggregated_indice'].map(volumefrom)
-    data['aggregated_high'] =  data['aggregated_indice'].map(high)
-    data['aggregated_low'] =  data['aggregated_indice'].map(low)
+    data['aggregated_volume'] =  data['aggregated_indice'].map(volumefrom).copy()
+    data['aggregated_high'] =  data['aggregated_indice'].map(high).copy()
+    data['aggregated_low'] =  data['aggregated_indice'].map(low).copy()
 
     data = data[::-lag]
     data = data.iloc[::-1]
@@ -1093,10 +1093,10 @@ def counting_candles_ls(data= None, low_threshold = 0.3, up_threshold = 0.8, con
     low = data.groupby(['aggregated_indice'])['low'].agg('min')
     close_diff = data.groupby(['aggregated_indice'])['close_diff'].agg('sum')
 
-    data['aggregated_volume'] =  data['aggregated_indice'].map(volumefrom)
-    data['aggregated_high'] =  data['aggregated_indice'].map(high)
-    data['aggregated_low'] =  data['aggregated_indice'].map(low)
-    data['aggregated_close_diff'] =  data['aggregated_indice'].map(close_diff)
+    data['aggregated_volume'] =  data['aggregated_indice'].map(volumefrom).copy()
+    data['aggregated_high'] =  data['aggregated_indice'].map(high).copy()
+    data['aggregated_low'] =  data['aggregated_indice'].map(low).copy()
+    data['aggregated_close_diff'] =  data['aggregated_indice'].map(close_diff).copy()
 
     data = data[::-lag]
     data = data.iloc[::-1]
@@ -1128,10 +1128,10 @@ def counting_candles_lo(data= None, up_threshold = 0.8, contravariant = -1., lag
     low = data.groupby(['aggregated_indice'])['low'].agg('min')
     close_diff = data.groupby(['aggregated_indice'])['close_diff'].agg('sum')
 
-    data['aggregated_volume'] =  data['aggregated_indice'].map(volumefrom)
-    data['aggregated_high'] =  data['aggregated_indice'].map(high)
-    data['aggregated_low'] =  data['aggregated_indice'].map(low)
-    data['aggregated_close_diff'] =  data['aggregated_indice'].map(close_diff)
+    data['aggregated_volume'] =  data['aggregated_indice'].map(volumefrom).copy()
+    data['aggregated_high'] =  data['aggregated_indice'].map(high).copy()
+    data['aggregated_low'] =  data['aggregated_indice'].map(low).copy()
+    data['aggregated_close_diff'] =  data['aggregated_indice'].map(close_diff).copy()
 
     data = data[::-lag]
     data = data.iloc[::-1]
