@@ -378,7 +378,7 @@ def recompute_perf_returns(signals_df, close_df, transac_cost=True, print_turnov
                 signals_returns_df[sig] = freqly_df.perf_return
     return signals_returns_df
 
-def daily_signal_hourlyzation(close, daily_signal, transaction_cost=True, method = 'interpolate'):
+def daily_signal_hourlyzation(close, daily_signal, transaction_cost=True, shift = None):
     if not isinstance(close, pd.DataFrame):
         close = pd.DataFrame(close)
     if not isinstance(daily_signal, pd.DataFrame):
@@ -390,14 +390,22 @@ def daily_signal_hourlyzation(close, daily_signal, transaction_cost=True, method
     daily_signal.columns = ['signal']
     daily_signal = daily_signal.fillna(0)
 
-    hourly_signal = daily_signal.asfreq(freq='H')
-    if method == 'interpolate':
-        print('interpolating')
-        hourly_signal['signal'] = hourly_signal['signal'].shift(1)
-        hourly_signal['signal'] = hourly_signal['signal'].interpolate(method='linear')
-    else:
+
+    if shift is None :
         print('forward filling')
+        hourly_signal = daily_signal.asfreq(freq='H')
         hourly_signal.signal = hourly_signal.signal.ffill()
+    else :
+        print('interpolating')
+        assert shift <=24
+        hourly_signal = daily_signal.asfreq(freq='H').copy()
+        hourly_signal = hourly_signal.shift(shift)
+        daily_signal = daily_signal.shift(1)
+        hourly_signal.loc[daily_signal.index] = daily_signal
+        print('pushing the signal '+str(shift) )
+        hourly_signal['signal'] = hourly_signal['signal'].interpolate(method='linear')
+
+
 
     starting_date = max(hourly_signal.index[0], close.index[0])
     running_date = min(hourly_signal.index[-1], close.index[-1])
